@@ -300,14 +300,14 @@ plot_brainGraph_gui <- function() {
           graphObj[[1]] <<- graphObjEntry[[1]]$getText()
           graphObj[[2]] <<- graphObjEntry[[2]]$getText()
 
-          if (!is.igraph(eval(parse(text=graphObj[[1]])))) {
+          if (!is_igraph(eval(parse(text=graphObj[[1]])))) {
             warnDialog <- gtkMessageDialog(parent=dialog, flags='destroy-with-parent',
                                            type='error', buttons='close',
                                            'Error: Not an igraph object!')
             response <- warnDialog$run()
             if (response == GtkResponseType['close']) warnDialog$destroy()
           } else {
-            if (nchar(graphObj[[2]]) > 0 & !is.igraph(eval(parse(text=graphObj[[2]])))) {
+            if (nchar(graphObj[[2]]) > 0 & !is_igraph(eval(parse(text=graphObj[[2]])))) {
               warnDialog <- gtkMessageDialog(parent=dialog, flags='destroy-with-parent',
                                              type='error', buttons='close',
                                              'Error: Not an igraph object!')
@@ -341,7 +341,7 @@ plot_brainGraph_gui <- function() {
   vboxMain$add(frame)
 
   vbox <- gtkVBoxNew(F, 2)
-  vbox$setBorderWidth(5)
+  vbox$setBorderWidth(3)
   frame$add(vbox)
 
   # Create a frame for each plot area
@@ -355,7 +355,7 @@ plot_brainGraph_gui <- function() {
     vbox$add(frameG[[i]])
 
     vboxG[[i]] <- gtkVBoxNew(F, 2)
-    vboxG[[i]]$setBorderWidth(10)
+    vboxG[[i]]$setBorderWidth(5)
     frameG[[i]]$add(vboxG[[i]])
 
     hbox <- gtkHBoxNew(F, 6)
@@ -386,19 +386,38 @@ plot_brainGraph_gui <- function() {
 
   # Should vertex labels be displayed?
   #---------------------------------------
-  hbox <- gtkHBoxNew(F, 6)
+  hbox <- gtkHBoxNew(F, 24)
   vbox$packStart(hbox, F, F, 0)
-  vertLabels <- add_check(hbox, 'Display vertex _labels?')
+
+  hboxLabels <- gtkHBoxNew(F, 6)
+  hbox$packStart(hboxLabels, F, F, 0)
+  vertLabels <- add_check(hboxLabels, 'Display vertex _labels?')
+
+  # Show a legend (for lobe colors)?
+  #---------------------------------------
+  hboxLegend <- gtkHBoxNew(F, 6)
+  hbox$packStart(hboxLegend, F, F, 0)
+  showLegend <- add_check(hboxLegend, 'Show le_gend?')
+  showLegend$setSensitive(F)
 
   # Vertex colors based on community membership?
   #---------------------------------------
   atlas <- graphs[[1]]$atlas
   hboxVcolor <- gtkHBoxNew(F, 6)
   vbox$packStart(hboxVcolor, F, F, 0)
-  choices <- c('None (lightblue)', 'Communities', 'Lobes', 'Components')
-  if (atlas == 'destrieux') choices <- c(choices, 'Class')
+  choices <- c('None (lightblue)', 'Communities', 'Lobes', 'Components',
+               'Communities (weighted)')
+  if (atlas %in% c('destrieux', 'destrieux.scgm')) choices <- c(choices, 'Class')
 
   comboVcolor <- add_combo(hboxVcolor, choices, 'Vertex _color')
+  gSignalConnect(comboVcolor, 'changed', function(widget, ...) {
+      i <- widget$getActive()
+      if (i %in% c(2, 5)) {
+        showLegend$setSensitive(T)
+      } else {
+        showLegend$setSensitive(F)
+      }
+  })
 
   #-----------------------------------------------------------------------------
   # Vertex size?
@@ -415,7 +434,10 @@ plot_brainGraph_gui <- function() {
                'Coreness', 'Clustering coeff.', 'PC',
                'E.local', 'E.nodal', 'Within-module degree z-score', 'Hub score',
                'Vulnerability', 'NN degree', 'Asymmetry', 'Eccentricity',
-               'Other', 'Equation')
+               'Distance', 'Distance strength', 'Lp', 'Other', 'Equation')
+  if (is_weighted(graphs[[1]])) {
+    choices <- c(choices, 'strength', 'knn.wt', 'E.local.wt', 'E.nodal.wt')
+  }
   comboVsize <- add_combo(hboxVsize, choices, 'Attribute')
   vertSize.const <- add_entry(hboxVsize, char.width=3, entry.text='5')
 
@@ -475,7 +497,8 @@ plot_brainGraph_gui <- function() {
   vsize.opts <<- c('const', 'degree', 'ev.cent', 'btwn.cent',
                   'coreness', 'transitivity', 'PC', 'E.local', 'E.nodal',
                   'z.score', 'hub.score', 'vulnerability', 'knn', 'asymm',
-                  'eccentricity')
+                  'eccentricity', 'dist', 'dist.strength', 'Lp', 'other', 'eqn',
+                  'strength', 'knn.wt', 'E.local.wt', 'E.nodal.wt')
   gSignalConnect(comboVsize, 'changed', function(widget, ...) {
       i <- widget$getActive()
       if (i == 0) {  # 'Constant'
@@ -488,21 +511,22 @@ plot_brainGraph_gui <- function() {
         vertSize.other$setSensitive(F)
         lapply(vertSize.spin, function(x) x$setSensitive(T))
         lapply(vertSizeEqn, function(x) x$setSensitive(F))
-        if (i < 15) {
-          if (i == 11 && !is.directed(graphs[[1]])) i <- 2
+        if (i < 18 | i > 19) {
+          if (i == 10 && !is_directed(graphs[[1]])) i <- 2
           for (j in seq_len(kNumGroups)) {
             rangeX <- range(vertex_attr(graphs[[j]], vsize.opts[i + 1]), na.rm=T)
             newMin <- rangeX[1]
             newMax <- rangeX[2]
-            newStep <- ifelse(diff(rangeX) > 1 & newMin >= 0, 1,
+            newStep <- ifelse(diff(rangeX) > 10 & newMin >= 0, 1,
                               ifelse(diff(rangeX) < 1, 0.01, 0.1))
-            newDigits <- ifelse(diff(rangeX) > 1 & newMin >= 0, 0, 2)
+            newDigits <- ifelse(diff(rangeX) > 10 & newMin >= 0, 0,
+                                ifelse(diff(rangeX) < 1, 2, 1))
             gtkSpinButtonSetDigits(vertSize.spin[[j]], newDigits)
             gtkSpinButtonSetIncrements(vertSize.spin[[j]], step=newStep, page=0)
             gtkSpinButtonSetRange(vertSize.spin[[j]], min=newMin, max=newMax)
             gtkSpinButtonSetValue(vertSize.spin[[j]], newMin)
           }
-        } else if (i == 15) {  # 'Other'
+        } else if (i == 18) {  # 'Other'
           vertSize.other$setSensitive(T)
           lapply(vertSizeEqn, function(x) x$setSensitive(F))
           lapply(vertSize.spin, function(x) x$setSensitive(T))
@@ -512,7 +536,7 @@ plot_brainGraph_gui <- function() {
             gtkSpinButtonSetRange(vertSize.spin[[j]], min=-100, max=100)
             gtkSpinButtonSetValue(vertSize.spin[[j]], 0)
           }
-        } else if (i == 16) {  # equation
+        } else if (i == 19) {  # equation
           lapply(vertSizeEqn, function(x) x$setSensitive(T))
           lapply(vertSize.spin, function(x) x$setSensitive(F))
         }
@@ -523,17 +547,27 @@ plot_brainGraph_gui <- function() {
   #gSignalConnect(vertSize.spin[[2]], 'value-changed', function(x) updateFun(2))
   #-----------------------------------------------------------------------------
   # Edge width?
-  hboxEwidth <- gtkHBoxNew(F, 6)
-  vbox$packStart(hboxEwidth, F, F, 0)
-  choices <- c('Constant', 'Edge betweenness', 'Distance')
-  if ('weight' %in% edge_attr_names(graphs[[1]])) choices <- c(choices, 'Weight')
-  comboEwidth <- add_combo(hboxEwidth, choices, 'Edge width')
+  #-----------------------------------------------------------------------------
+  frameEwidth <- gtkFrameNew('Edge width')
+  vbox$add(frameEwidth)
 
+  vboxEwidth <- gtkVBoxNew(F, 2)
+  frameEwidth$add(vboxEwidth)
+
+  hboxEwidth <- gtkHBoxNew(F, 6)
+  vboxEwidth$packStart(hboxEwidth, F, F, 0)
+  choices <- c('Constant', 'Edge betweenness', 'Distance', 'Other')
+  if ('weight' %in% edge_attr_names(graphs[[1]])) choices <- c(choices, 'Weight')
+  comboEwidth <- add_combo(hboxEwidth, choices, 'Attribute')
   edgeWidth.const <- add_entry(hboxEwidth, char.width=3, entry.text='1')
 
-  # Have 2 entries to allow for min's of 2 groups
   hboxEwidthOther <- gtkHBoxNew(F, 6)
-  vbox$packStart(hboxEwidthOther, F, F, 0)
+  vboxEwidth$packStart(hboxEwidthOther, F, F, 0)
+  edgeWidth.other <- add_entry(hboxEwidthOther, label.text=paste0('\t', 'Other:'),
+                              char.width=10)
+  edgeWidth.other$setSensitive(F)
+
+  # Have 2 entries to allow for min's of 2 groups
   for (i in 1:2) {
     hboxEwidthMin[[i]] <- gtkHBoxNew(F, 6)
     hboxEwidthOther$packStart(hboxEwidthMin[[i]], T, F, 0)
@@ -545,14 +579,26 @@ plot_brainGraph_gui <- function() {
     edgeWidth.spin[[i]]$setSensitive(F)
   }
 
-  ewidth.opts <<- c('const', 'btwn', 'dist', 'weight')
+  ewidth.opts <<- c('const', 'btwn', 'dist', 'other', 'weight')
   gSignalConnect(comboEwidth, 'changed', function(widget, ...) {
     i <- widget$getActive()
     if (i == 0) {  # 'Constant'
       edgeWidth.const$setSensitive(T)
+      edgeWidth.other$setSensitive(F)
       lapply(edgeWidth.spin, function(x) x$setSensitive(F))
+    } else if (i == 3) {  # 'Other'
+      edgeWidth.const$setSensitive(F)
+      edgeWidth.other$setSensitive(T)
+      lapply(edgeWidth.spin, function(x) x$setSensitive(T))
+      for (j in seq_len(kNumGroups)) {
+        gtkSpinButtonSetDigits(edgeWidth.spin[[j]], 2)
+        gtkSpinButtonSetIncrements(edgeWidth.spin[[j]], step=0.01, page=0)
+        gtkSpinButtonSetRange(edgeWidth.spin[[j]], min=-100, max=100)
+        gtkSpinButtonSetValue(edgeWidth.spin[[j]], 0)
+      }
     } else {
       edgeWidth.const$setSensitive(F)
+      edgeWidth.other$setSensitive(F)
       lapply(edgeWidth.spin, function(x) x$setSensitive(T))
       for (j in seq_len(kNumGroups)) {
         rangeX <- range(edge_attr(graphs[[j]], ewidth.opts[i + 1]), na.rm=T)
@@ -605,27 +651,21 @@ plot_brainGraph_gui <- function() {
   #---------------------------------------------------------
   # Create 2 drawing areas for the plotting
   #---------------------------------------------------------
-  # Check screen resolution so the plotting window fits
   if (.Platform$OS.type == 'windows') {
-    screen.x <- 1600
+    scr_width <- system("wmic desktopmonitor get screenwidth", intern=TRUE)
+    scr_height <- system("wmic desktopmonitor get screenheight", intern=TRUE)
+    res <- as.numeric(c(scr_width[-c(1, length(scr_width))],
+                        scr_height[-c(1, length(scr_height))]))
   } else {
-  display.size <- system('xdpyinfo | grep dimensions', intern=T)
-  m <- regexpr(' [0-9]+x', display.size)
-  res <- regmatches(display.size, m)
-  screen.x <- as.numeric(sub('x', '', sub(' ', '', res)))
+    display.size <- system("xrandr | grep '*' | awk '{print $1}'", intern=T)
+    res <- as.numeric(strsplit(display.size, 'x')[[1]])
   }
 
-  if (screen.x <= 1440) {
-    graphics.res <- 460
-  } else if (screen.x > 1440 && screen.x <= 1680) {
-    graphics.res <- 560
-  } else {
-    graphics.res <- 640
-  }
+  ydim <- ifelse(res[2] < 800, 0.8 * res[2], 700)
 
   for (i in 1:2) {
     graphics[[i]] <- gtkDrawingArea()
-    graphics[[i]]$setSizeRequest(graphics.res, graphics.res)
+    graphics[[i]]$setSizeRequest(res[1] / 3 - 10, ydim)#0.8 * res[2])#graphics.res, graphics.res)
 
     vboxPlot[[i]] <- gtkVBox()
     vboxPlot[[i]]$packStart(graphics[[i]], expand=T, fill=T, padding=0)
@@ -657,9 +697,10 @@ plot_brainGraph_gui <- function() {
                           orient=comboOrient[[j]], vertSize.min=vertSize.spin[[j]],
                           edgeWidth.min=edgeWidth.spin[[j]],
                           vertSize.const=vertSize.const, edgeWidth.const=edgeWidth.const,
-                          vertLabels, comm=comboComm, kNumComms=kNumComms,
+                          vertLabels=vertLabels, showLegend=showLegend,
+                          comm=comboComm, kNumComms=kNumComms,
                           neighb=comboNeighb, neighbMult=comboNeighbMult,
-                          slider=slider[[j]], vertSize.other,
+                          slider=slider[[j]], vertSize.other, edgeWidth.other,
                           vertSize.eqn=vertSizeEqn[[j]], showDiameter=showDiameter, edgeDiffs)
   }
   gSignalConnect(btnOK, 'clicked', function(widget) {
